<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'Estatìstica de SPIP',
	'stats_nom' => 'Estatìstica',
	'stats_slogan' => 'Gestioun dei estatìstica en SPIP',
];
